#ifndef DEVICE_H
#define DEVICE_H

#include "fly-device_global.h"

#include <QObject>
#include <QVariant>

namespace Solid {
    class Device;
    class StorageAccess;
}

class FLYDEVICESHARED_EXPORT Device : public QObject
{
    Q_OBJECT
public:
    explicit Device(const QString &udi,
                    Solid::StorageAccess *device,
                    QObject *parent = nullptr);
    ~Device();

    QString udi() const;
    QString name() const;
    bool isMounted() const;
    void mount();
    //! Solid doesn't support normal umount for some reason
    //! It's "teardown" method unmounts AND remove /dev/sdX
    void eject();
    QString mountpoint() const;

signals:
    void mounted();
    void unmounted();
    void mountFailed(const QString &title, const QString &description);
    void ejected();
    void ejectFailed(const QString &title, const QString &description);

private slots:
    void onAccessibilityChanged(bool accessible, const QString &udi);

private:
    QString blockDeviceName(const Solid::Device &device) const;

    QString m_udi;
    Solid::StorageAccess *m_device;
};

#endif // DEVICE_H
